/*globals define, window*/
/*jslint nomen:true*/

define([
    'testsuite/qunit',
    'testsuite/qunit-fixture!ep/ui/core-test',
    'jquery',
    'ep/ui/core',

    '$ready!'
], function (QUnit, fixture, $, ep) {

    'use strict';

    QUnit.module('ep.ui.core', {
        setup: fixture.init,
        teardown: fixture.destroy
    });

    QUnit.asyncTest('ep.ui.imgData() && ep.ui.imgCenter', function () {
        // We have to execute the ep.ui.imgData and ep.ui.imgCenter test
        // in one test because there is a strange timing problem in QUnit.

        // Start test: ep.ui.imgData()
        var i1 = ep.ui.imgData('#images1 img'),
            i2 = ep.ui.imgData('#images2 img'),
            i3 = ep.ui.imgData($('#images2 li img')),
            i4 = ep.ui.imgData('ep/ui/core-test.jpg'),
            i5 = ep.ui.imgData({
                desc: 'Object 1',
                src: 'ep/ui/core-test.jpg'
            }),
            i6 = ep.ui.imgData([ 'ep/ui/core-test.jpg', {desc: 'Object 2', src: 'ep/ui/core-test.jpg'}]),
            e1 = false;

        QUnit.equal(
            i1.length,
            5,
            "ep.ui.imgData('#images1 img').length"
        );

        QUnit.equal(
            i2.length,
            2,
            "ep.ui.imgData('#images2 img').length"
        );

        i1.each(function (i, item) {
            QUnit.equal(
                item.desc,
                "Logo " + (i + 1),
                "ep.ui.imgData('#images1 img').each( ... item.desc ... )"
            );
        });

        i2.each(function (i, item) {
            QUnit.equal(
                item.desc,
                "Title " + (i + 1),
                "ep.ui.imgData('#images2 img').each( ... item.desc ... )"
            );
        });

        i3.each(function (i, item) {
            QUnit.equal(
                item.desc,
                "Title " + (i + 1),
                "ep.ui.imgData( $('#images2 li img') ).each( ... item.desc ... )"
            );
        });

        i4.each(function (i, item) {
            QUnit.equal(
                item.src,
                'ep/ui/core-test.jpg',
                "ep.ui.imgData( 'ep/ui/core-test.jpg' ).each( ... item.src ... )"
            );
            QUnit.equal(
                item.desc,
                '',
                "ep.ui.imgData( 'ep/ui/core-test.jpg' ).each( ... item.desc ... )"
            );
        });

        i5.each(function (i, item) {
            QUnit.equal(
                item.src,
                'ep/ui/core-test.jpg',
                "ep.ui.imgData( {...} ).each( ... item.src ... )"
            );
            QUnit.equal(
                item.desc,
                'Object 1',
                "ep.ui.imgData( {...} ).each( ... item.desc ... )"
            );
        });

        i6.each(function (i, item) {
            QUnit.equal(
                (item.desc || 'Object 1'),
                'Object ' + (i + 1),
                "ep.ui.imgData( {...} ).each( ... item.desc ... )"
            );
        });

        QUnit.equal(
            typeof i1.current(),
            'object',
            "typeof ep.ui.imgData('#images1 img').current()"
        );

        QUnit.equal(
            i1.current().desc,
            'Logo 1',
            "ep.ui.imgData('#images1 img').current().desc"
        );

        QUnit.equal(
            i1.current(2).current().desc,
            'Logo 3',
            "ep.ui.imgData('#images1 img').current(2).current().desc"
        );

        QUnit.equal(
            i1.current(10).current().desc,
            'Logo 3',
            "ep.ui.imgData('#images1 img').current(10).current().desc"
        );

        QUnit.equal(
            i1.current('prev').current().desc,
            'Logo 2',
            "ep.ui.imgData('#images1 img').current('prev').current().desc"
        );

        QUnit.equal(
            i1.current('next').current().desc,
            'Logo 3',
            "ep.ui.imgData('#images1 img').current('next').current().desc"
        );

        QUnit.equal(
            i1.next().desc,
            'Logo 4',
            "ep.ui.imgData('#images1 img').next().desc"
        );

        QUnit.equal(
            i1.prev().desc,
            'Logo 2',
            "ep.ui.imgData('#images1 img').prev().desc"
        );

        QUnit.equal(
            i1.first().desc,
            'Logo 1',
            "ep.ui.imgData('#images1 img').first().desc"
        );

        QUnit.equal(
            i1.last().desc,
            'Logo 5',
            "ep.ui.imgData('#images1 img').last().desc"
        );

        i1.on('change', function () {
            e1 = !e1;
        });
        i1.current(1);

        QUnit.equal(
            e1,
            true,
            "ep.ui.imgData('#images1 img').on('change', toggle(e1) ).current(1); e1"
        );

        i1.off('change');
        i1.current(3);

        QUnit.equal(
            e1,
            true,
            "ep.ui.imgData('#images1 img').off('change').current(3); e1"
        );

        i1.on('resize', function () {
            e1 = !e1;
        });

        i1.on('resizestop', function () {
            e1 = !e1;
        });

        $(window).trigger('resize');

        QUnit.equal(
            e1,
            false,
            "ep.ui.imgData('#images1 img').on('resize', toggle(e1) ); .trigger(...); e1"
        );

        setTimeout(function () {

            QUnit.equal(
                e1,
                true,
                "ep.ui.imgData('#images1 img').on('resizestop', toggle(e1) ); .trigger(...); e1"
            );

            QUnit.start();

        }, 200);
        // End test: ep.ui.imgData()
    });
});