/*global define, window*/
/*jslint nomen:true, vars:true*/
define([
    'testsuite/qunit',
    'testsuite/qunit-fixture!./facebook-test.html',
    'jquery',

    './facebook',
    '$ready!'
], function (QUnit, fixture, $) {
    'use strict';

    QUnit.module('de_epages/externalcontent/ui/facebook', {
        setup: fixture.init,
        teardown: fixture.destroy
    });

    QUnit.test('Test facebook methods', 2, function () {
        $.each(['_create', 'destroy'], function (i, fn) {
            QUnit.equal(
                $.isFunction($.ui.externalcontentUiFacebook.prototype[fn]),
                true,
                fn + ' is a method of facebook'
            );
        });
    });

    QUnit.test('Test facebook', 14, function () {
        window.element = null;

        window.FB = {
            XFBML: {
                parse: function (_element) {
                    window.element = _element;
                }
            }
        };

        $.ajax = function (o) {
            return {
                done: function (_func) {
                    _func();
                }
            };
        };

        $("#facebookplugin1").externalcontentUiFacebook({
            action: "like",
            layout: "standard",
            send: true,
            showFaces: true
        });

        QUnit.equal(
            $('#fb-root').length,
            1,
            "the jQuery object with all div elements with id='fb-root' got the right length = 1"
        );

        QUnit.equal(
            $.isFunction(window.fbAsyncInit),
            true,
            "the function window.fbAsyncInit is executed"
        );

        QUnit.equal(
            window.element.id,
            $("#facebookplugin1").attr("id"),
            "the plugin is appended to the correct div"
        );

        QUnit.equal(
            $(window.element).children().attr("class"),
            "fb-like",
            "the appended div has the correct class = <fb-like>"
        );

        $("#facebookplugin2").externalcontentUiFacebook({
            action: "recommend",
            layout: "standard",
            send: true,
            showFaces: true
        });

        QUnit.equal(
            $('#fb-root').length,
            1,
            "the jQuery object with all div elements with id='fb-root' got the right length = 1"
        );

        QUnit.equal(
            $.isFunction(window.fbAsyncInit),
            true,
            "the function window.fbAsyncInit is executed"
        );

        QUnit.equal(
            window.element.id,
            $("#facebookplugin2").attr("id"),
            "the plugin is appended to the correct div"
        );

        QUnit.equal(
            $(window.element).children().attr("class"),
            "fb-like",
            "the appended div has the correct class = <fb-like>"
        );

        $("#facebookplugin3").externalcontentUiFacebook({
            boxMode: true,
            showFaces: true,
            showStream: true
        });

        QUnit.equal(
            $('#fb-root').length,
            1,
            "the jQuery object with all div elements with id='fb-root' got the right length = 1"
        );

        QUnit.equal(
            $.isFunction(window.fbAsyncInit),
            true,
            "the function window.fbAsyncInit is executed"
        );

        QUnit.equal(
            window.element.id,
            $("#facebookplugin3").attr("id"),
            "the plugin is appended to the correct div"
        );

        QUnit.equal(
            $(window.element).children().attr("class"),
            "fb-like-box",
            "the appended div has the correct class = <fb-like-box>"
        );

        $("div[id^=facebookplugin]").each(function () {
            $(this).externalcontentUiFacebook("destroy");
        });

        var hasClassSocialWeb = true;

        $("div[id^=facebookplugin]").each(function () {
            var value = $(this).hasClass("SocialWeb");
            if (hasClassSocialWeb !== value) {
                hasClassSocialWeb = value;
            }
        });

        var ChildNodes = 1;

        $("div[id^=facebookplugin]").each(function () {
            var value = $(this).children().length;
            if (ChildNodes !== value) {
                ChildNodes = value;
            }
        });

        QUnit.equal(
            hasClassSocialWeb,
            false,
            "the destroy method has successfully deleted the class SocialWeb from every <<div>> "
        );

        QUnit.equal(
            ChildNodes,
            0,
            "the destroy method has successfully disappended all child elements, length of child elements from each <<div>> = 0"
        );
    });
});